@@ -12,13 +12,14 @@ __all__ = ['GridPipeCell',
            'GridPipeFile',
            'GridPipeNode']
 
+from future.utils import iteritems
 from sqlalchemy import ForeignKey, Column
 from sqlalchemy.types import Integer, Float, String
 from sqlalchemy.orm import relationship
 
-from gsshapy.orm import DeclarativeBase
-from gsshapy.base.file_base import GsshaPyFileObjectBase
-from gsshapy.lib import parsetools as pt
+from . import DeclarativeBase
+from ..base.file_base import GsshaPyFileObjectBase
+from ..lib import parsetools as pt
 
 
 class GridPipeFile(DeclarativeBase, GsshaPyFileObjectBase):
@@ -70,8 +71,8 @@ class GridPipeFile(DeclarativeBase, GsshaPyFileObjectBase):
         with open(path, 'r') as f:
             chunks = pt.chunk(KEYWORDS, f)
 
-        # Parse chunks associated with each key    
-        for key, chunkList in chunks.iteritems():
+        # Parse chunks associated with each key
+        for key, chunkList in iteritems(chunks):
             # Parse each chunk in the chunk list
             for chunk in chunkList:
 
@@ -143,8 +144,8 @@ class GridPipeFile(DeclarativeBase, GsshaPyFileObjectBase):
 
         chunks = pt.chunk(KEYWORDS, lines)
 
-        # Parse chunks associated with each key    
-        for card, chunkList in chunks.iteritems():
+        # Parse chunks associated with each key
+        for card, chunkList in iteritems(chunks):
             # Parse each chunk in the chunk list
             for chunk in chunkList:
                 schunk = chunk[0].strip().split()
