@@ -15,13 +15,14 @@ __all__ = ['StormPipeNetworkFile',
            'SuperJunction',
            'Connection']
 
+from future.utils import iteritems
 from sqlalchemy import ForeignKey, Column
 from sqlalchemy.types import Integer, Float, String
 from sqlalchemy.orm import relationship
 
-from gsshapy.orm import DeclarativeBase
-from gsshapy.base.file_base import GsshaPyFileObjectBase
-from gsshapy.lib import parsetools as pt, spn_chunk as spc
+from . import DeclarativeBase
+from ..base.file_base import GsshaPyFileObjectBase
+from ..lib import parsetools as pt, spn_chunk as spc
 
 
 class StormPipeNetworkFile(DeclarativeBase, GsshaPyFileObjectBase):
@@ -80,8 +81,8 @@ class StormPipeNetworkFile(DeclarativeBase, GsshaPyFileObjectBase):
         with open(path, 'r') as f:
             chunks = pt.chunk(KEYWORDS, f)
 
-        # Parse chunks associated with each key    
-        for key, chunkList in chunks.iteritems():
+        # Parse chunks associated with each key
+        for key, chunkList in iteritems(chunks):
             # Parse each chunk in the chunk list
             for chunk in chunkList:
                 # Call chunk specific parsers for each chunk
@@ -487,4 +488,4 @@ class Connection(DeclarativeBase):
         return '<Connection: SlinkNumber=%s, UpSjuncNumber=%s, DownSjuncNumber=%s>' % (
             self.slinkNumber,
             self.upSjuncNumber,
-            self.downSjuncNumber)
\ No newline at end of file
+            self.downSjuncNumber)
